==========
Change Log
==========

`0.3.0`_ (2019-01-14)
---------------------
- `ethindex --version` will now print the current version of ethindex.
- `ethindex` has been set as entrypoint in the docker executable. Beware, this
  is a breaking change.

`0.2.1`_ (2019-01-03)
-----------------------
* reduce log output when fully synced

`0.2.0`_ (2018-09-07)
-----------------------
* ethindex handles chain reorgs
* the database schema has been changed. Please rebuild your database
* new contracts can now be added

`0.1.1`_ (2018-08-21)
-----------------------
* eth-index has been released on PyPI
* basic test infrastructure has been added


.. _0.1.1: https://github.com/trustlines-protocol/py-eth-index/compare/0.1.0...0.1.1
.. _0.2.0: https://github.com/trustlines-protocol/py-eth-index/compare/0.1.1...0.2.0
.. _0.2.1: https://github.com/trustlines-protocol/py-eth-index/compare/0.2.0...0.2.1
.. _0.3.0: https://github.com/trustlines-protocol/py-eth-index/compare/0.2.1...0.3.0
